@@ -61,10 +61,10 @@ class SlimtaState(object):
 
     @contextmanager
     def _with_pid_file(self):
-        pid_file = os.path.abspath(self.args.pid_file)
-        if not pid_file:
+        if not self.args.pid_file:
             yield
         else:
+            pid_file = os.path.abspath(self.args.pid_file)
             with open(pid_file, 'w') as f:
                 f.write('{0}\n'.format(os.getpid()))
             try:
@@ -151,15 +151,32 @@ class SlimtaState(object):
         new_relay = None
         if options.type == 'mx':
             from slimta.relay.smtp.mx import MxSmtpRelay
-            ehlo_as = options.get('ehlo_as')
-            new_relay = MxSmtpRelay(ehlo_as=ehlo_as)
+            from .helpers import fill_hostname_template
+            kwargs = {}
+            kwargs['connect_timeout'] = options.get('connect_timeout', 30)
+            kwargs['command_timeout'] = options.get('command_timeout', 30)
+            kwargs['data_timeout'] = options.get('data_timeout', 60)
+            kwargs['idle_timeout'] = options.get('idle_timeout', 10)
+            kwargs['pool_size'] = options.get('concurrent_connections', 5)
+            kwargs['ehlo_as'] = fill_hostname_template(options.get('ehlo_as'))
+            if 'tls' in options:
+                kwargs['tls'] = dict(options.tls)
+            new_relay = MxSmtpRelay(**kwargs)
         elif options.type == 'static':
             from slimta.relay.smtp.static import StaticSmtpRelay
             from .helpers import fill_hostname_template
-            host = options.host
-            port = options.get('port', 25)
-            ehlo_as = fill_hostname_template(options.get('ehlo_as'))
-            new_relay = StaticSmtpRelay(host, port, ehlo_as=ehlo_as)
+            kwargs = {}
+            kwargs['host'] = options.host
+            kwargs['port'] = options.get('port', 25)
+            kwargs['connect_timeout'] = options.get('connect_timeout', 30)
+            kwargs['command_timeout'] = options.get('command_timeout', 30)
+            kwargs['data_timeout'] = options.get('data_timeout', 60)
+            kwargs['idle_timeout'] = options.get('idle_timeout', 10)
+            kwargs['pool_size'] = options.get('concurrent_connections', 5)
+            kwargs['ehlo_as'] = fill_hostname_template(options.get('ehlo_as'))
+            if 'tls' in options:
+                kwargs['tls'] = dict(options.tls)
+            new_relay = StaticSmtpRelay(**kwargs)
         elif options.type == 'maildrop':
             from slimta.maildroprelay import MaildropRelay
             executable = options.get('executable')
@@ -272,7 +289,7 @@ class SlimtaState(object):
                 with self._with_pid_file():
                     get_celery_worker(self.celery).run()
         except (KeyboardInterrupt, SystemExit):
-            print
+            pass
 
     def loop(self):
         from gevent.event import Event
@@ -281,7 +298,7 @@ class SlimtaState(object):
                 with self._with_pid_file():
                     Event().wait()
         except (KeyboardInterrupt, SystemExit):
-            print
+            pass
 
 
 # vim:et:fdm=marker:sts=4:sw=4:ts=4
